@@ -17,6 +17,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
 #include "atkimage.h"
 
 /**
@@ -208,11 +210,11 @@ atk_image_get_image_position (AtkImage *image,
  * atk_image_get_image_locale: 
  * @image: An #AtkImage
  *
- * Since ATK 1.12
+ * Since: 1.12
  *
- * Returns: a string corresponding to the POSIX LC_MESSAGES locale
- * used by the image description, or NULL if the image does not
- * specify a locale.
+ * Returns: (nullable): a string corresponding to the POSIX
+ * LC_MESSAGES locale used by the image description, or %NULL if the
+ * image does not specify a locale.
  *
  */
 const gchar*
