@@ -17,6 +17,8 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
 #include "atk.h"
 #include "atkmarshal.h"
 
@@ -199,7 +201,7 @@ atk_text_base_init (AtkTextIface *class)
        * "delete" which identifies whether the text change was an
        * insertion or a deletion.
        *
-       * Deprecated: Since 2.9.4. Use #AtkObject::text-insert or
+       * Deprecated: 2.9.4: Use #AtkObject::text-insert or
        * #AtkObject::text-remove instead.
        */
       atk_text_signals[TEXT_CHANGED] =
@@ -380,8 +382,7 @@ atk_text_get_character_at_offset (AtkText      *text,
  *
  * Gets the specified text.
  *
- * Deprecated: This method is deprecated since ATK version
- * 2.9.3. Please use atk_text_get_string_at_offset() instead.
+ * Deprecated: 2.9.3: Please use atk_text_get_string_at_offset() instead.
  *
  * Returns: a newly allocated string containing the text after @offset bounded
  *   by the specified @boundary_type. Use g_free() to free the returned string.
@@ -500,8 +501,7 @@ atk_text_get_text_at_offset (AtkText          *text,
  *
  * Gets the specified text.
  *
- * Deprecated: This method is deprecated since ATK version
- * 2.9.3. Please use atk_text_get_string_at_offset() instead.
+ * Deprecated: 2.9.3: Please use atk_text_get_string_at_offset() instead.
  *
  * Returns: a newly allocated string containing the text before @offset bounded
  *   by the specified @boundary_type. Use g_free() to free the returned string.
@@ -582,9 +582,10 @@ atk_text_get_text_before_offset (AtkText          *text,
  *
  * Since: 2.10
  *
- * Returns: a newly allocated string containing the text at the @offset bounded
- *   by the specified @granularity. Use g_free() to free the returned string.
- *   Returns %NULL if the offset is invalid or no implementation is available.
+ * Returns: (nullable): a newly allocated string containing the text
+ *   at the @offset bounded by the specified @granularity. Use
+ *   g_free() to free the returned string.  Returns %NULL if the
+ *   offset is invalid or no implementation is available.
  **/
 gchar* atk_text_get_string_at_offset (AtkText *text,
                                       gint offset,
@@ -1261,8 +1262,9 @@ atk_text_attribute_for_name (const gchar *name)
  *
  * Gets the value for the index of the #AtkTextAttribute
  *
- * Returns: a string containing the value; this string should not be freed;
- * NULL is returned if there are no values maintained for the attr value. 
+ * Returns: (nullable): a string containing the value; this string
+ * should not be freed; %NULL is returned if there are no values
+ * maintained for the attr value.
  **/
 const gchar*
 atk_text_attribute_get_value (AtkTextAttribute attr,
